//[mahjong-utils](../../../../index.md)/[mahjongutils.models](../../index.md)/[Tatsu](../index.md)/[Companion](index.md)/[parse](parse.md)

# parse

[common]\
fun [parse](parse.md)(first: [Tile](../../-tile/index.md), second: [Tile](../../-tile/index.md)): [Tatsu](../index.md)

根据给定牌构造搭子

#### Return

搭子

#### Parameters

common

| | |
|---|---|
| first | 第一张牌 |
| second | 第二张牌 |

[common]\
fun [parse](parse.md)(text: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)): [Tatsu](../index.md)

根据给定牌的文本构造搭子

#### Return

搭子

#### Parameters

common

| | |
|---|---|
| text | 牌的文本 |
